@@ -16,17 +16,23 @@ pub fn get() -> Option<Info> {
     };
 
     let os_type = match release.distribution.as_ref().map(String::as_ref) {
+        Some("Alpaquita") => Type::Alpaquita,
         Some("Amazon") | Some("AmazonAMI") => Type::Amazon,
         Some("Arch") => Type::Arch,
+        Some("Artix") => Type::Artix,
         Some("CentOS") => Type::CentOS,
         Some("Debian") => Type::Debian,
         Some("EndeavourOS") => Type::EndeavourOS,
         Some("Fedora") | Some("Fedora Linux") => Type::Fedora,
+        Some("Garuda") => Type::Garuda,
         Some("Gentoo") => Type::Gentoo,
         Some("Linuxmint") => Type::Mint,
+        Some("MaboxLinux") => Type::Mabox,
         Some("ManjaroLinux") => Type::Manjaro,
         Some("Mariner") => Type::Mariner,
         Some("NixOS") => Type::NixOS,
+        Some("OpenCloudOS") => Type::OpenCloudOS,
+        Some("openEuler") => Type::openEuler,
         Some("openSUSE") => Type::openSUSE,
         Some("OracleServer") => Type::OracleLinux,
         Some("Pop") => Type::Pop,
@@ -107,6 +113,14 @@ mod tests {
         assert_eq!(parse_results.codename, Some("wheezy".to_string()));
     }
 
+    #[test]
+    fn alpaquita() {
+        let parse_results = parse(alpaquita_file());
+        assert_eq!(parse_results.distribution, Some("Alpaquita".to_string()));
+        assert_eq!(parse_results.version, Some("23".to_string()));
+        assert_eq!(parse_results.codename, None);
+    }
+
     #[test]
     fn arch() {
         let parse_results = parse(arch_file());
@@ -115,6 +129,14 @@ mod tests {
         assert_eq!(parse_results.codename, None);
     }
 
+    #[test]
+    fn artix() {
+        let parse_results = parse(artix_file());
+        assert_eq!(parse_results.distribution, Some("Artix".to_string()));
+        assert_eq!(parse_results.version, Some("rolling".to_string()));
+        assert_eq!(parse_results.codename, None);
+    }
+
     #[test]
     fn fedora() {
         let parse_results = parse(fedora_file());
@@ -295,6 +317,13 @@ mod tests {
          "
     }
 
+    fn alpaquita_file() -> &'static str {
+        "\nDistributor ID: Alpaquita\n\
+        Description:    BellSoft Alpaquita Linux Stream 23 (musl)\n\
+        Release:        23\n\
+        Codename:       n/a"
+    }
+
     fn arch_file() -> &'static str {
         "\nLSB Version:	1.4\n\
          Distributor ID:	Arch\n\
@@ -303,6 +332,14 @@ mod tests {
          Codename:	n/a"
     }
 
+    fn artix_file() -> &'static str {
+        "\nLSB Version:	n/a\n\
+         Distributor ID:	Artix\n\
+         Description:	Artix Linux\n\
+         Release:	rolling\n\
+         Codename:	n/a"
+    }
+
     fn fedora_file() -> &'static str {
         "\nLSB Version:    :core-4.1-amd64:core-4.1-noarch:cxx-4.1-amd64:cxx-4.1-noarch\n\
          Distributor ID: Fedora\n\
